/**
 * P4
 * http://snarfed.org/space/p4
 *
 * Copyright 2001-2004
 * Ken Ashcraft <kashcraft+p4@gmail.com>
 * Ryan Barrett <p4@ryanb.org>
 * Maulik Shah <p4@maulik.net>
 * Nathan Stoll <nathanstoll+p4@gmail.com>
 *
 * File: mock_p4plugin.h
 *
 * The header that P4 plugins should use to compile. Exports all of the API
 * functions as C prototypes.
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef _MOCK_P4PLUGIN_H
#define _MOCK_P4PLUGIN_H

#include "p4plugin.h"
#include <sys/types.h>

/*****************************************************************************
 * THESE FUNCTIONS ARE <<ONLY>> FOR THE MOCK BACKEND
 *****************************************************************************/

/** p4_mock_connect
 *
 * Opens a TCP connection to another computer. The address parameter should be
 * either a fully qualified hostname (e.g. "blaize.stanford.edu") or an IP
 * address represented as a string (e.g. "128.12.75.93"). The port parameter is
 * the port to connect to. The computer at the given address should be
 * listening for a p4 connection with p4_mock_listen().
 *
 * Returns true if a connection was established successfully, false otherwise.
 */
void p4_mock_connect(char *address, ushort port);


/** p4_mock_connect
 *
 * Listens for a P4 TCP connection on a given port. 
 *
 * Returns true if a connection was established successfully, false otherwise.
 */
void p4_mock_listen(ushort port);


/** p4_mock_disconnect
 *
 * Disconnects the current P4 connection. Returns true if it disconnected
 * successfully, false if it was not originally connected.
 */
void p4_mock_disconnect();



#endif  // _MOCK_P4PLUGIN_H


